@@ -13,8 +13,7 @@ QwtPainterClass
    :members:
 """
 
-from qtpy import QtCore as QC
-from qtpy.QtCore import QLineF, QPoint, QRect, QRectF, Qt
+from qtpy.QtCore import QLineF, QPoint, QRect, Qt
 from qtpy.QtGui import (
     QBrush,
     QColor,
@@ -27,13 +26,17 @@ from qtpy.QtGui import (
     QPixmap,
     QRegion,
 )
-from qtpy.QtWidgets import QFrame, QStyle, QStyleOption, QStyleOptionFocusRect
+from qtpy.QtWidgets import (
+    QApplication,
+    QFrame,
+    QStyle,
+    QStyleOption,
+    QStyleOptionFocusRect,
+)
 
 from qwt.color_map import QwtColorMap
 from qwt.scale_map import QwtScaleMap
 
-QT_MAJOR_VERSION = int(QC.__version__.split(".")[0])
-
 QWIDGETSIZE_MAX = (1 << 24) - 1
 
 
@@ -63,12 +66,6 @@ def qwtFillRect(widget, painter, rect, brush):
 class QwtPainterClass(object):
     """A collection of `QPainter` workarounds"""
 
-    def drawImage(self, painter, rect, image):
-        painter.drawImage(rect, image)
-
-    def drawPixmap(self, painter, rect, pixmap):
-        painter.drawPixmap(rect, pixmap)
-
     def drawFocusRect(self, *args):
         if len(args) == 2:
             painter, widget = args
@@ -88,40 +85,6 @@ class QwtPainterClass(object):
                 "(s) (%s given)" % len(args)
             )
 
-    def drawRoundFrame(self, painter, rect, palette, lineWidth, frameStyle):
-        """
-        Draw a round frame
-
-        :param QPainter painter: Painter
-        :param QRectF rect: Target rectangle
-        :param QPalette palette: `QPalette.WindowText` is used for plain borders, `QPalette.Dark` and `QPalette.Light` for raised or sunken borders
-        :param int lineWidth: Line width
-        :param int frameStyle: bitwise OR´ed value of `QFrame.Shape` and `QFrame.Shadow`
-        """
-        Plain, Sunken, Raised = list(range(3))
-        style = Plain
-        if (frameStyle & QFrame.Sunken) == QFrame.Sunken:
-            style = Sunken
-        elif (frameStyle & QFrame.Raised) == QFrame.Raised:
-            style = Raised
-        lw2 = 0.5 * lineWidth
-        r = rect.adjusted(lw2, lw2, -lw2, -lw2)
-        if style != Plain:
-            c1 = palette.color(QPalette.Light)
-            c2 = palette.color(QPalette.Dark)
-            if style == Sunken:
-                c1, c2 = c2, c1
-            gradient = QLinearGradient(r.topLeft(), r.bottomRight())
-            gradient.setColorAt(0.0, c1)
-            gradient.setColorAt(1.0, c2)
-            brush = QBrush(gradient)
-        else:
-            brush = palette.brush(QPalette.WindowText)
-        painter.save()
-        painter.setPen(QPen(brush, lineWidth))
-        painter.drawEllipse(r)
-        painter.restore()
-
     def drawFrame(
         self,
         painter,
@@ -443,25 +406,14 @@ class QwtPainterClass(object):
         :param QSize size: Size of the pixmap
         :return: A pixmap that can be used as backing store
         """
-        if QT_MAJOR_VERSION >= 5:
-            pixelRatio = 1.0
-            if widget and widget.windowHandle():
-                pixelRatio = widget.windowHandle().devicePixelRatio()
-            else:
-                from qtpy.QtGui import qApp
-
-                if qApp is not None:
-                    try:
-                        pixelRatio = qApp.devicePixelRatio()
-                    except RuntimeError:
-                        pass
-            pm = QPixmap(size * pixelRatio)
-            pm.setDevicePixelRatio(pixelRatio)
+        pixelRatio = 1.0
+        if widget and widget.windowHandle():
+            pixelRatio = widget.windowHandle().devicePixelRatio()
         else:
-            pm = QPixmap(size)
-        if QT_MAJOR_VERSION < 5 and widget and isX11GraphicsSystem():
-            if pm.x11Info().screen() != widget.x11Info().screen():
-                pm.x11SetScreen(widget.x11Info().screen())
+            qapp = QApplication.instance()
+            pixelRatio = qapp.devicePixelRatio()
+        pm = QPixmap(size * pixelRatio)
+        pm.setDevicePixelRatio(pixelRatio)
         return pm
 
 
